@@ -4,6 +4,8 @@
 
 from flasket import endpoint
 
+from gl_webhooks.controllers import jobs_monitor
+
 from .webhooks.gitlab import jobs
 
 
@@ -18,7 +20,7 @@ gl_webhooks_service_status 1
 """
 
     # Metrics for api webhooks/gitlab/jobs.py
-    data = jobs.atomic_file_action(app, None)
+    data = jobs_monitor.atomic_file_action(None)
     pending = len([True for v in data.values() if v["status"] == "pending"])
     running = len([True for v in data.values() if v["status"] == "running"])
     retval += """
