@@ -47,14 +47,16 @@ def insert(settings, body):
         data[build_id]["build_id"] = int(build_id)
         data[build_id]["project_id"] = int(project_id)
         data[build_id]["status"] = build_status
-        data[build_id]["web_url"] = body.get("web_url")
+        if body.get("web_url"):
+            data[build_id]["web_url"] = body.get("web_url")
 
         # Get a possible updated status
         if build_status not in FINAL_STATES:
             try:
                 job = gl.projects.get(int(project_id), lazy=True).jobs.get(int(build_id))
                 data[build_id]["status"] = job.status
-                data[build_id]["web_url"] = job.web_url
+                if job.web_url:
+                    data[build_id]["web_url"] = job.web_url
             except:
                 pass
 
